@@ -67,7 +67,8 @@ int yk_release(void)
 
 YK_KEY *yk_open_first_key(void)
 {
-	int pids[] = {YUBIKEY_PID, NEO_OTP_PID, NEO_OTP_CCID_PID};
+	int pids[] = {YUBIKEY_PID, NEO_OTP_PID, NEO_OTP_CCID_PID,
+		NEO_OTP_U2F_PID, NEO_OTP_U2F_CCID_PID};
 
 	YK_KEY *yk = _ykusb_open_device(YUBICO_VID, pids, sizeof(pids));
 	int rc = yk_errno;
@@ -121,7 +122,8 @@ int yk_check_firmware_version2(YK_STATUS *st)
 	      (st->versionMajor == 3 &&
 	       (st->versionMinor == 0 ||
 		st->versionMinor == 1 ||
-		st->versionMinor == 2)))) {
+		st->versionMinor == 2 ||
+		st->versionMinor == 3)))) {
 		yk_errno = YK_EFIRMWARE;
 		return 0;
 	}
@@ -704,6 +706,10 @@ int yk_force_key_update(YK_KEY *yk)
 	return 1;
 }
 
+int yk_get_key_vid_pid(YK_KEY *yk, int *vid, int *pid) {
+	return _ykusb_get_vid_pid(yk, vid, pid);
+}
+
 uint16_t yk_endian_swap_16(uint16_t x)
 {
 	static int testflag = -1;
