@@ -1,6 +1,6 @@
 /* -*- mode:C; c-file-style: "bsd" -*- */
 /*
- * Copyright (c) 2008-2012 Yubico AB
+ * Copyright (c) 2008-2014 Yubico AB
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -35,12 +35,13 @@ const char *usage;
 
 int args_to_config(int argc, char **argv, YKP_CONFIG *cfg, YK_KEY *yk,
 		   const char **infname, const char **outfname,
-		   bool *autocommit, char *salt,
-		   YK_STATUS *st, bool *verbose,
+		   int *data_format, bool *autocommit,
+		   YK_STATUS *st, bool *verbose, bool *dry_run,
 		   unsigned char *access_code, bool *use_access_code,
-		   bool *aesviahash, char *ndef_type, char *ndef,
-		   int *exit_code);
+		   char *keylocation, char *ndef_type, char *ndef, unsigned char *usb_mode,
+		   bool *zap, unsigned char *scan_bin, unsigned char *cr_timeout,
+		   unsigned char *autoeject_timeout, int *num_modes_seen, int *exit_code);
 
-void report_yk_error();
+void report_yk_error(void);
 
 #endif
